@@ -428,7 +428,7 @@ class ReferenceCrystal(Record):
         query.str_match.mongo(mquery, f'{root}.source.name', sourcename)
         query.str_match.mongo(mquery, f'{root}.sourcelink', sourcelink)
         query.str_match.mongo(mquery, f'{root}.system-info.cell.crystal-family', crystalfamily)
-        query.str_match.mongo(mquery, f'{root}.system-info.cell.composition', composition)
+        query.str_match.mongo(mquery, f'{root}.system-info.composition', composition)
         query.in_list.mongo(mquery, f'{root}.system-info.symbol', symbols)
         query.str_match.mongo(mquery, f'{root}.atomic-system.atoms.natoms', natoms)
         query.str_match.mongo(mquery, f'{root}.system-info.cell.natypes', natypes)
@@ -475,7 +475,7 @@ class ReferenceCrystal(Record):
         query.str_match.mongo(mquery, f'{root}.source.name', sourcename)
         query.str_match.mongo(mquery, f'{root}.sourcelink', sourcelink)
         query.str_match.mongo(mquery, f'{root}.system-info.cell.crystal-family', crystalfamily)
-        query.str_match.mongo(mquery, f'{root}.system-info.cell.composition', composition)
+        query.str_match.mongo(mquery, f'{root}.system-info.composition', composition)
         query.in_list.mongo(mquery, f'{root}.system-info.symbol', symbols)
         query.str_match.mongo(mquery, f'{root}.atomic-system.atoms.natoms', natoms)
         query.str_match.mongo(mquery, f'{root}.system-info.cell.natypes', natypes)
