@@ -441,7 +441,7 @@ class RelaxedCrystal(Record):
         query.str_match.mongo(mquery, f'{root}.potential-LAMMPS.potential.id', potential_id)
         query.str_match.mongo(mquery, f'{root}.potential-LAMMPS.potential.key', potential_key)
         query.str_match.mongo(mquery, f'{root}.system-info.cell.crystal-family', crystalfamily)
-        query.str_match.mongo(mquery, f'{root}.system-info.cell.composition', composition)
+        query.str_match.mongo(mquery, f'{root}.system-info.composition', composition)
         query.in_list.mongo(mquery, f'{root}.system-info.symbol', symbols)
         query.str_match.mongo(mquery, f'{root}.atomic-system.atoms.natoms', natoms)
         query.str_match.mongo(mquery, f'{root}.system-info.cell.natypes', natypes)
@@ -509,7 +509,7 @@ class RelaxedCrystal(Record):
         query.str_match.mongo(mquery, f'{root}.potential-LAMMPS.potential.id', potential_id)
         query.str_match.mongo(mquery, f'{root}.potential-LAMMPS.potential.key', potential_key)
         query.str_match.mongo(mquery, f'{root}.system-info.cell.crystal-family', crystalfamily)
-        query.str_match.mongo(mquery, f'{root}.system-info.cell.composition', composition)
+        query.str_match.mongo(mquery, f'{root}.system-info.composition', composition)
         query.in_list.mongo(mquery, f'{root}.system-info.symbol', symbols)
         query.str_match.mongo(mquery, f'{root}.atomic-system.atoms.natoms', natoms)
         query.str_match.mongo(mquery, f'{root}.system-info.cell.natypes', natypes)
